summaryrefslogtreecommitdiffstats
path: root/kig/objects
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:43 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:43 -0600
commit2d7b541a4e0095d40e37aaefbf9c4a9b9d149302 (patch)
tree628c1676b27475e583cfd0c2105bb41b646654bf /kig/objects
parent6c3f7a55fb7888efc80a7350ef0c2f46ee02baa3 (diff)
downloadtdeedu-2d7b541a4e0095d40e37aaefbf9c4a9b9d149302.tar.gz
tdeedu-2d7b541a4e0095d40e37aaefbf9c4a9b9d149302.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 6c3f7a55fb7888efc80a7350ef0c2f46ee02baa3.
Diffstat (limited to 'kig/objects')
-rw-r--r--kig/objects/bogus_imp.cc8
-rw-r--r--kig/objects/circle_imp.cc16
-rw-r--r--kig/objects/conic_imp.cc20
-rw-r--r--kig/objects/cubic_imp.cc20
-rw-r--r--kig/objects/line_imp.cc4
-rw-r--r--kig/objects/object_calcer.cc12
-rw-r--r--kig/objects/object_calcer.h6
-rw-r--r--kig/objects/object_factory.cc6
-rw-r--r--kig/objects/object_holder.cc2
-rw-r--r--kig/objects/object_imp.h2
-rw-r--r--kig/objects/object_imp_factory.cc40
-rw-r--r--kig/objects/point_imp.cc2
-rw-r--r--kig/objects/point_type.cc2
-rw-r--r--kig/objects/text_type.cc4
14 files changed, 72 insertions, 72 deletions
diff --git a/kig/objects/bogus_imp.cc b/kig/objects/bogus_imp.cc
index b7b8f41e..5c68c30c 100644
--- a/kig/objects/bogus_imp.cc
+++ b/kig/objects/bogus_imp.cc
@@ -88,22 +88,22 @@ InvalidImp::InvalidImp()
void InvalidImp::fillInNextEscape( TQString& s, const KigDocument& ) const
{
- s = s.arg( "[invalid]" );
+ s = s.tqarg( "[invalid]" );
}
void DoubleImp::fillInNextEscape( TQString& s, const KigDocument& ) const
{
- s = s.arg( mdata );
+ s = s.tqarg( mdata );
}
void IntImp::fillInNextEscape( TQString& s, const KigDocument& ) const
{
- s = s.arg( mdata );
+ s = s.tqarg( mdata );
}
void StringImp::fillInNextEscape( TQString& s, const KigDocument& ) const
{
- s = s.arg( mdata );
+ s = s.tqarg( mdata );
}
HierarchyImp::HierarchyImp( const ObjectHierarchy& h )
diff --git a/kig/objects/circle_imp.cc b/kig/objects/circle_imp.cc
index 38522c22..4b6c1123 100644
--- a/kig/objects/circle_imp.cc
+++ b/kig/objects/circle_imp.cc
@@ -235,8 +235,8 @@ TQString CircleImp::polarEquationString( const KigDocument& w ) const
{
TQString ret = i18n( "rho = %1 [centered at %2]" );
ConicPolarData data = polarData();
- ret = ret.arg( data.pdimen, 0, 'g', 3 );
- ret = ret.arg( w.coordinateSystem().fromScreen( data.focus1, w ) );
+ ret = ret.tqarg( data.pdimen, 0, 'g', 3 );
+ ret = ret.tqarg( w.coordinateSystem().fromScreen( data.focus1, w ) );
return ret;
}
@@ -244,18 +244,18 @@ TQString CircleImp::cartesianEquationString( const KigDocument& ) const
{
TQString ret = i18n( "x² + y² + %1 x + %2 y + %3 = 0" );
ConicCartesianData data = cartesianData();
- ret = ret.arg( data.coeffs[3], 0, 'g', 3 );
- ret = ret.arg( data.coeffs[4], 0, 'g', 3 );
- ret = ret.arg( data.coeffs[5], 0, 'g', 3 );
+ ret = ret.tqarg( data.coeffs[3], 0, 'g', 3 );
+ ret = ret.tqarg( data.coeffs[4], 0, 'g', 3 );
+ ret = ret.tqarg( data.coeffs[5], 0, 'g', 3 );
return ret;
}
TQString CircleImp::simplyCartesianEquationString( const KigDocument& ) const
{
TQString ret = i18n( "( x - %1 )² + ( y - %2 )² = %3" );
- ret = ret.arg( mcenter.x, 0, 'g', 3 );
- ret = ret.arg( mcenter.y, 0, 'g', 3 );
- ret = ret.arg( mradius * mradius, 0, 'g', 3 );
+ ret = ret.tqarg( mcenter.x, 0, 'g', 3 );
+ ret = ret.tqarg( mcenter.y, 0, 'g', 3 );
+ ret = ret.tqarg( mradius * mradius, 0, 'g', 3 );
return ret;
}
diff --git a/kig/objects/conic_imp.cc b/kig/objects/conic_imp.cc
index 81331522..5828fc98 100644
--- a/kig/objects/conic_imp.cc
+++ b/kig/objects/conic_imp.cc
@@ -204,12 +204,12 @@ TQString ConicImp::cartesianEquationString( const KigDocument& ) const
{
TQString ret = i18n( "%1 x² + %2 y² + %3 xy + %4 x + %5 y + %6 = 0" );
ConicCartesianData data = cartesianData();
- ret = ret.arg( data.coeffs[0], 0, 'g', 3 );
- ret = ret.arg( data.coeffs[1], 0, 'g', 3 );
- ret = ret.arg( data.coeffs[2], 0, 'g', 3 );
- ret = ret.arg( data.coeffs[3], 0, 'g', 3 );
- ret = ret.arg( data.coeffs[4], 0, 'g', 3 );
- ret = ret.arg( data.coeffs[5], 0, 'g', 3 );
+ ret = ret.tqarg( data.coeffs[0], 0, 'g', 3 );
+ ret = ret.tqarg( data.coeffs[1], 0, 'g', 3 );
+ ret = ret.tqarg( data.coeffs[2], 0, 'g', 3 );
+ ret = ret.tqarg( data.coeffs[3], 0, 'g', 3 );
+ ret = ret.tqarg( data.coeffs[4], 0, 'g', 3 );
+ ret = ret.tqarg( data.coeffs[5], 0, 'g', 3 );
return ret;
}
@@ -218,11 +218,11 @@ TQString ConicImp::polarEquationString( const KigDocument& w ) const
TQString ret = i18n( "rho = %1/(1 + %2 cos theta + %3 sin theta)\n [centered at %4]" );
const ConicPolarData data = polarData();
- ret = ret.arg( data.pdimen, 0, 'g', 3 );
- ret = ret.arg( -data.ecostheta0, 0, 'g', 3 );
- ret = ret.arg( -data.esintheta0, 0, 'g', 3 );
+ ret = ret.tqarg( data.pdimen, 0, 'g', 3 );
+ ret = ret.tqarg( -data.ecostheta0, 0, 'g', 3 );
+ ret = ret.tqarg( -data.esintheta0, 0, 'g', 3 );
- ret = ret.arg( w.coordinateSystem().fromScreen( data.focus1, w ) );
+ ret = ret.tqarg( w.coordinateSystem().fromScreen( data.focus1, w ) );
return ret;
}
diff --git a/kig/objects/cubic_imp.cc b/kig/objects/cubic_imp.cc
index 9fc8c53c..b4a85b8e 100644
--- a/kig/objects/cubic_imp.cc
+++ b/kig/objects/cubic_imp.cc
@@ -417,18 +417,18 @@ TQString CubicImp::cartesianEquationString( const KigDocument& ) const
*/
TQString ret = i18n( "%6 x³ + %9 y³ + %7 x²y + %8 xy² + %5 y² + %3 x² + %4 xy + %1 x + %2 y" );
- ret = ret.arg( mdata.coeffs[1], 0, 'g', 3 );
- ret = ret.arg( mdata.coeffs[2], 0, 'g', 3 );
- ret = ret.arg( mdata.coeffs[3], 0, 'g', 3 );
- ret = ret.arg( mdata.coeffs[4], 0, 'g', 3 );
- ret = ret.arg( mdata.coeffs[5], 0, 'g', 3 );
- ret = ret.arg( mdata.coeffs[6], 0, 'g', 3 );
- ret = ret.arg( mdata.coeffs[7], 0, 'g', 3 );
- ret = ret.arg( mdata.coeffs[8], 0, 'g', 3 );
- ret = ret.arg( mdata.coeffs[9], 0, 'g', 3 );
+ ret = ret.tqarg( mdata.coeffs[1], 0, 'g', 3 );
+ ret = ret.tqarg( mdata.coeffs[2], 0, 'g', 3 );
+ ret = ret.tqarg( mdata.coeffs[3], 0, 'g', 3 );
+ ret = ret.tqarg( mdata.coeffs[4], 0, 'g', 3 );
+ ret = ret.tqarg( mdata.coeffs[5], 0, 'g', 3 );
+ ret = ret.tqarg( mdata.coeffs[6], 0, 'g', 3 );
+ ret = ret.tqarg( mdata.coeffs[7], 0, 'g', 3 );
+ ret = ret.tqarg( mdata.coeffs[8], 0, 'g', 3 );
+ ret = ret.tqarg( mdata.coeffs[9], 0, 'g', 3 );
ret.append( i18n( " + %1 = 0" ) );
- ret = ret.arg( mdata.coeffs[0], 0, 'g', 3 );
+ ret = ret.tqarg( mdata.coeffs[0], 0, 'g', 3 );
// we should find a common place to do this...
ret.replace( "+ -", "- " );
diff --git a/kig/objects/line_imp.cc b/kig/objects/line_imp.cc
index a49078a1..7583dc71 100644
--- a/kig/objects/line_imp.cc
+++ b/kig/objects/line_imp.cc
@@ -186,8 +186,8 @@ const TQString AbstractLineImp::equationString() const
TQString::fromUtf8( r > 0 ? "+" : "-" ) +
TQString::fromUtf8( " %2" );
- ret = ret.arg( m, 0, 'g', 3 );
- ret = ret.arg( abs( r ), 0, 'g', 3 );
+ ret = ret.tqarg( m, 0, 'g', 3 );
+ ret = ret.tqarg( abs( r ), 0, 'g', 3 );
return ret;
}
diff --git a/kig/objects/object_calcer.cc b/kig/objects/object_calcer.cc
index 40545ed1..0bf4e774 100644
--- a/kig/objects/object_calcer.cc
+++ b/kig/objects/object_calcer.cc
@@ -106,16 +106,16 @@ std::vector<ObjectCalcer*> ObjectTypeCalcer::parents() const
void ObjectCalcer::addChild( ObjectCalcer* c )
{
- mchildren.push_back( c );
+ mtqchildren.push_back( c );
ref();
}
void ObjectCalcer::delChild( ObjectCalcer* c )
{
- std::vector<ObjectCalcer*>::iterator i = std::find( mchildren.begin(), mchildren.end(), c );
- assert( i != mchildren.end() );
+ std::vector<ObjectCalcer*>::iterator i = std::find( mtqchildren.begin(), mtqchildren.end(), c );
+ assert( i != mtqchildren.end() );
- mchildren.erase( i );
+ mtqchildren.erase( i );
deref();
}
@@ -175,9 +175,9 @@ ObjectImp* ObjectConstCalcer::switchImp( ObjectImp* newimp )
return ret;
}
-std::vector<ObjectCalcer*> ObjectCalcer::children() const
+std::vector<ObjectCalcer*> ObjectCalcer::tqchildren() const
{
- return mchildren;
+ return mtqchildren;
}
const ObjectImpType* ObjectPropertyCalcer::impRequirement(
diff --git a/kig/objects/object_holder.cc b/kig/objects/object_holder.cc
index cdf06396..b6c5f09e 100644
--- a/kig/objects/object_holder.cc
+++ b/kig/objects/object_holder.cc
@@ -160,5 +160,5 @@ TQString ObjectHolder::selectStatement() const
if ( n.isEmpty() )
return i18n( imp()->type()->selectStatement() );
else
- return i18n( imp()->type()->selectNameStatement() ).arg( n );
+ return i18n( imp()->type()->selectNameStatement() ).tqarg( n );
}
diff --git a/kig/objects/object_imp.h b/kig/objects/object_imp.h
index eaf29328..ddf0eb46 100644
--- a/kig/objects/object_imp.h
+++ b/kig/objects/object_imp.h
@@ -170,7 +170,7 @@ public:
* Returns a translatable string of the form "Select point %1". %1
* will be filled in by whomever calls this function with the name
* of the object in question. This function should be used as
- * follows: i18n( x->selectNameStatement() ).arg( xname ).
+ * follows: i18n( x->selectNameStatement() ).tqarg( xname ).
*/
const char* selectNameStatement() const;
diff --git a/kig/objects/object_imp_factory.cc b/kig/objects/object_imp_factory.cc
index d095c238..a29cf5e8 100644
--- a/kig/objects/object_imp_factory.cc
+++ b/kig/objects/object_imp_factory.cc
@@ -84,33 +84,33 @@ TQString ObjectImpFactory::serialize( const ObjectImp& d, TQDomElement& parent,
parent.appendChild(
doc.createTextNode(
TQString::number( static_cast<const IntImp&>( d ).data() ) ) );
- return TQString::fromLatin1( "int" );
+ return TQString::tqfromLatin1( "int" );
}
else if ( d.inherits( DoubleImp::stype() ) )
{
parent.appendChild(
doc.createTextNode(
TQString::number( static_cast<const DoubleImp&>( d ).data() ) ) );
- return TQString::fromLatin1( "double" );
+ return TQString::tqfromLatin1( "double" );
}
else if( d.inherits( StringImp::stype() ) )
{
parent.appendChild(
doc.createTextNode(
static_cast<const StringImp&>( d ).data() ) );
- return TQString::fromLatin1( "string" );
+ return TQString::tqfromLatin1( "string" );
}
else if ( d.inherits( TestResultImp::stype() ) )
{
parent.appendChild(
doc.createTextNode(
static_cast<const TestResultImp&>( d ).data() ) );
- return TQString::fromLatin1( "testresult" );
+ return TQString::tqfromLatin1( "testresult" );
}
else if( d.inherits( HierarchyImp::stype() ) )
{
static_cast<const HierarchyImp&>( d ).data().serialize( parent, doc );
- return TQString::fromLatin1( "hierarchy" );
+ return TQString::tqfromLatin1( "hierarchy" );
}
else if ( d.inherits( TransformationImp::stype() ) )
{
@@ -135,7 +135,7 @@ TQString ObjectImpFactory::serialize( const ObjectImp& d, TQDomElement& parent,
homothetye.appendChild( doc.createTextNode( ishomothety ) );
parent.appendChild( homothetye );
- return TQString::fromLatin1( "transformation" );
+ return TQString::tqfromLatin1( "transformation" );
}
else if( d.inherits( AbstractLineImp::stype() ) )
{
@@ -143,28 +143,28 @@ TQString ObjectImpFactory::serialize( const ObjectImp& d, TQDomElement& parent,
addCoordinateElement( "a", l.a, parent, doc );
addCoordinateElement( "b", l.b, parent, doc );
if( d.inherits( SegmentImp::stype() ) )
- return TQString::fromLatin1( "segment" );
+ return TQString::tqfromLatin1( "segment" );
else if( d.inherits( RayImp::stype() ) )
- return TQString::fromLatin1( "ray" );
- else return TQString::fromLatin1( "line" );
+ return TQString::tqfromLatin1( "ray" );
+ else return TQString::tqfromLatin1( "line" );
}
else if( d.inherits( PointImp::stype() ) )
{
addXYElements( static_cast<const PointImp&>( d ).coordinate(),
parent, doc );
- return TQString::fromLatin1( "point" );
+ return TQString::tqfromLatin1( "point" );
}
else if( d.inherits( TextImp::stype() ) )
{
TQString text = static_cast<const TextImp&>( d ).text();
parent.appendChild(
doc.createTextNode( text ) );
- return TQString::fromLatin1( "text" );
+ return TQString::tqfromLatin1( "text" );
}
else if( d.inherits( AngleImp::stype() ) )
{
addDoubleElement( "size", static_cast<const AngleImp&>( d ).size(), parent, doc );
- return TQString::fromLatin1( "angle" );
+ return TQString::tqfromLatin1( "angle" );
}
else if ( d.inherits( ArcImp::stype() ) )
{
@@ -173,13 +173,13 @@ TQString ObjectImpFactory::serialize( const ObjectImp& d, TQDomElement& parent,
addDoubleElement( "radius", a.radius(), parent, doc );
addDoubleElement( "startangle", a.startAngle(), parent, doc );
addDoubleElement( "angle", a.angle(), parent, doc );
- return TQString::fromLatin1( "arc" );
+ return TQString::tqfromLatin1( "arc" );
}
else if( d.inherits( VectorImp::stype() ) )
{
Coordinate dir = static_cast<const VectorImp&>( d ).dir();
addXYElements( dir, parent, doc );
- return TQString::fromLatin1( "vector" );
+ return TQString::tqfromLatin1( "vector" );
}
else if( d.inherits( LocusImp::stype() ) )
{
@@ -197,14 +197,14 @@ TQString ObjectImpFactory::serialize( const ObjectImp& d, TQDomElement& parent,
locus.hierarchy().serialize( hier, doc );
parent.appendChild( hier );
- return TQString::fromLatin1( "locus" );
+ return TQString::tqfromLatin1( "locus" );
}
else if( d.inherits( CircleImp::stype() ) )
{
const CircleImp& c = static_cast<const CircleImp&>( d );
addCoordinateElement( "center", c.center(), parent, doc );
addDoubleElement( "radius", c.radius(), parent, doc );
- return TQString::fromLatin1( "circle" );
+ return TQString::tqfromLatin1( "circle" );
}
else if( d.inherits( ConicImp::stype() ) )
{
@@ -213,7 +213,7 @@ TQString ObjectImpFactory::serialize( const ObjectImp& d, TQDomElement& parent,
addDoubleElement( "pdimen", data.pdimen, parent, doc );
addDoubleElement( "ecostheta0", data.ecostheta0, parent, doc );
addDoubleElement( "esintheta0", data.esintheta0, parent, doc );
- return TQString::fromLatin1( "conic" );
+ return TQString::tqfromLatin1( "conic" );
}
else if( d.inherits( CubicImp::stype() ) )
{
@@ -230,7 +230,7 @@ TQString ObjectImpFactory::serialize( const ObjectImp& d, TQDomElement& parent,
addDoubleElement( "a122", data.coeffs[8], coeffs, doc );
addDoubleElement( "a222", data.coeffs[9], coeffs, doc );
parent.appendChild( coeffs );
- return TQString::fromLatin1( "cubic" );
+ return TQString::tqfromLatin1( "cubic" );
}
assert( false );
return TQString();
@@ -291,7 +291,7 @@ ObjectImp* ObjectImpFactory::deserialize( const TQString& type,
#define KIG_GENERIC_PARSE_ERROR \
{ \
error = i18n( "An error was encountered at line %1 in file %2." ) \
- .arg( __LINE__ ).arg( __FILE__ ); \
+ .tqarg( __LINE__ ).tqarg( __FILE__ ); \
return 0; \
}
@@ -504,7 +504,7 @@ ObjectImp* ObjectImpFactory::deserialize( const TQString& type,
"which this Kig version does not support."
"Perhaps you have compiled Kig without support "
"for this object type,"
- "or perhaps you are using an older Kig version." ).arg( type );
+ "or perhaps you are using an older Kig version." ).tqarg( type );
return 0;
}
diff --git a/kig/objects/point_imp.cc b/kig/objects/point_imp.cc
index 539f98b3..1e5b8766 100644
--- a/kig/objects/point_imp.cc
+++ b/kig/objects/point_imp.cc
@@ -137,7 +137,7 @@ void PointImp::setCoordinate( const Coordinate& c )
void PointImp::fillInNextEscape( TQString& s, const KigDocument& doc ) const
{
- s = s.arg( doc.coordinateSystem().fromScreen( mc, doc ) );
+ s = s.tqarg( doc.coordinateSystem().fromScreen( mc, doc ) );
}
void PointImp::visit( ObjectImpVisitor* vtor ) const
diff --git a/kig/objects/point_type.cc b/kig/objects/point_type.cc
index 2acd8479..f1c59ac4 100644
--- a/kig/objects/point_type.cc
+++ b/kig/objects/point_type.cc
@@ -395,7 +395,7 @@ void FixedPointType::executeAction(
Coordinate oldc = static_cast<const PointImp*>( o.imp() )->coordinate();
KigInputDialog::getCoordinate(
i18n( "Set Coordinate" ),
- i18n( "Enter the new coordinate." ) + TQString::fromLatin1( "<br>" ) +
+ i18n( "Enter the new coordinate." ) + TQString::tqfromLatin1( "<br>" ) +
d.document().coordinateSystem().coordinateFormatNoticeMarkup(),
&w, &ok, d.document(), &oldc );
if ( ! ok ) break;
diff --git a/kig/objects/text_type.cc b/kig/objects/text_type.cc
index 0b5832cd..09e84c30 100644
--- a/kig/objects/text_type.cc
+++ b/kig/objects/text_type.cc
@@ -30,7 +30,7 @@
#include <algorithm>
-#include <clipboard.h>
+#include <tqclipboard.h>
#include <tqstringlist.h>
#include <kapplication.h>
@@ -144,7 +144,7 @@ void TextType::executeAction( int i, ObjectHolder& o, ObjectTypeCalcer& c,
if ( i == 0 )
{
- TQClipboard* cb = kapp->clipboard();
+ TQClipboard* cb = kapp->tqclipboard();
// copy the text into the clipboard
const TextImp* ti = static_cast<const TextImp*>( c.imp() );
diff --git a/kig/objects/object_calcer.h b/kig/objects/object_calcer.h
index 6df94fe8..98262e5e 100644
--- a/kig/objects/object_calcer.h
+++ b/kig/objects/object_calcer.h
@@ -77,10 +77,10 @@ protected:
void ref();
void deref();
// we keep track of our children, so algorithms can easily walk over
// the dependency graph..
- std::vector<ObjectCalcer*> mchildren;
+ std::vector<ObjectCalcer*> mtqchildren;
ObjectCalcer();
public:
@@ -102,7 +102,7 @@ public:
/**
* Returns the child ObjectCalcer's of this ObjectCalcer.
*/
- std::vector<ObjectCalcer*> children() const;
+ std::vector<ObjectCalcer*> tqchildren() const;
virtual ~ObjectCalcer();
/**
@@ -77,10 +77,10 @@ protected:
void ref();
void deref();
- // we keep track of our children, so algorithms can easily walk over
+ // we keep track of our tqchildren, so algorithms can easily walk over
// the dependency graph..
diff --git a/kig/objects/object_factory.cc b/kig/objects/object_factory.cc
index f2957a7e..942139f4 100644
--- a/kig/objects/object_factory.cc
+++ b/kig/objects/object_factory.cc
@@ -299,12 +299,12 @@ void ObjectFactory::redefinePoint(
std::mem_fun( calcmeth ) );
ObjectCalcer* v = 0;
- // we don't want one of our children as a parent...
- std::set<ObjectCalcer*> children = getAllChildren( point );
+ // we don't want one of our tqchildren as a parent...
+ std::set<ObjectCalcer*> tqchildren = getAllChildren( point );
for ( std::vector<ObjectCalcer*>::iterator i = os.begin();
i != os.end(); ++i )
if ( (*i)->imp()->inherits( CurveImp::stype() ) &&
- children.find( *i ) == children.end() )
+ tqchildren.find( *i ) == tqchildren.end() )
{
v = *i;
break;